# CardSharp

## Description

CardSharp is a Python package for simulating and testing card games. The package currently supports Blackjack but can be extended to support more card games.

## Key Features

1. Simulation of multiple games in a batch.
2. Configurable game rules.
3. Test and console-based IO interfaces.

## Installation

1. Clone the repository.
2. Navigate to the project directory
3. Install dependencies with Poetry.

## Usage


You can run blackjack simulation mode with:

```
$ poetry shell
$ python blackjack.py --simulate --num_games 100
```

For more usage instructions, please refer to the documentation and the code comments.

## Contributing

Contributions are welcome!

## License

This project is licensed under the terms of the MIT license.
